# Политика безопасности

Спасибо за интерес к проекту и за ответственное отношение к сообщению об уязвимостях.

---

## Поддерживаемые версии

Обновления безопасности распространяются на **последнюю стабильную серию** релизов (текущую мажорную/минорную ветку).

Актуальные релизы: [Releases](https://github.com/RTHeLL/wbsdk/releases).

---

## Как сообщить об уязвимости

- **Не создавайте публичный issue** — описание уязвимости не должно появляться в открытых issues.
- Рекомендуемый способ: **GitHub Security Advisories**. Откройте вкладку **Security** репозитория и нажмите **Report a vulnerability**. Будет создан приватный draft advisory и диалог с мейнтейнерами.

---

## Что ожидать

- Подтверждение получения отчёта.
- Ориентировочный срок ответа — в течение нескольких дней.
- После исправления — упоминание в релизе; при желании благодарность в advisory с указанием имени исследователя (по согласию).

---

## Область применения

Мы рассматриваем уязвимости в **коде или зависимостях wbsdk** (например, утечка токенов при использовании SDK, небезопасная обработка данных, критические уязвимости в зависимостях).

Вопросы безопасности **API Wildberries** (серверная часть, политики WB) направляйте в поддержку Wildberries.
